/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02258
 |         DRUG ABUSE TREATMENT OUTCOME STUDY (DATOS), 1991-1994:
 |                            [UNITED STATES]
 |                (DATASET 0005:  ILLEGAL ACTIVITIES DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02258-0005-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study (DATOS), 1991-1994: [United States], Dataset 0005"

#delimit ;
label define MODALITY  1 "RESIDENTIAL" 2 "SHORT-TERM INPATIENT"
                       3 "METHADONE MAINTENANCE" 4 "OUTPATIENT DRUG FREE" ;
label define IADATE_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define IADATE_Y  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AIA1_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA1_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA1_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA1_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AIA2_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA2_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA2_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA2_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AIA3_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA3_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA3_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA3_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA4_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA4_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA4_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA4_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AIA5_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA5_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA5_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA5_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AIA6_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA6_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA6_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA6_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA7_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA7_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA7_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA7_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA8_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA8_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA8_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA8_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA9_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA9_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA9_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA9_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA10_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AIA10_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AIA10_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AIA10_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace IADATE_M = . if (IADATE_M <= -1 )
replace IADATE_Y = . if (IADATE_Y <= -1 )
replace AIA1_1 = . if (AIA1_1 <= -1 )
replace AIA1_2 = . if (AIA1_2 <= -1 )
replace AIA1_3 = . if (AIA1_3 <= -1 )
replace AIA1_4 = . if (AIA1_4 <= -1 )
replace AIA2_1 = . if (AIA2_1 <= -1 )
replace AIA2_2 = . if (AIA2_2 <= -1 )
replace AIA2_3 = . if (AIA2_3 <= -1 )
replace AIA2_4 = . if (AIA2_4 <= -1 )
replace AIA3_1 = . if (AIA3_1 <= -1 )
replace AIA3_2 = . if (AIA3_2 <= -1 )
replace AIA3_3 = . if (AIA3_3 <= -1 )
replace AIA3_4 = . if (AIA3_4 <= -1 )
replace AIA4_1 = . if (AIA4_1 <= -1 )
replace AIA4_2 = . if (AIA4_2 <= -1 )
replace AIA4_3 = . if (AIA4_3 <= -1 )
replace AIA4_4 = . if (AIA4_4 <= -1 )
replace AIA5_1 = . if (AIA5_1 <= -1 )
replace AIA5_2 = . if (AIA5_2 <= -1 )
replace AIA5_3 = . if (AIA5_3 <= -1 )
replace AIA5_4 = . if (AIA5_4 <= -1 )
replace AIA6_1 = . if (AIA6_1 <= -1 )
replace AIA6_2 = . if (AIA6_2 <= -1 )
replace AIA6_3 = . if (AIA6_3 <= -1 )
replace AIA6_4 = . if (AIA6_4 <= -1 )
replace AIA7_1 = . if (AIA7_1 <= -1 )
replace AIA7_2 = . if (AIA7_2 <= -1 )
replace AIA7_3 = . if (AIA7_3 <= -1 )
replace AIA7_4 = . if (AIA7_4 <= -1 )
replace AIA8_1 = . if (AIA8_1 <= -1 )
replace AIA8_2 = . if (AIA8_2 <= -1 )
replace AIA8_3 = . if (AIA8_3 <= -1 )
replace AIA8_4 = . if (AIA8_4 <= -1 )
replace AIA9_1 = . if (AIA9_1 <= -1 )
replace AIA9_2 = . if (AIA9_2 <= -1 )
replace AIA9_3 = . if (AIA9_3 <= -1 )
replace AIA9_4 = . if (AIA9_4 <= -1 )
replace AIA10_1 = . if (AIA10_1 <= -1 )
replace AIA10_2 = . if (AIA10_2 <= -1 )
replace AIA10_3 = . if (AIA10_3 <= -1 )
replace AIA10_4 = . if (AIA10_4 <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

